"""
monday.client
~~~~~~~~~~~~~~~~~~

:copyright: (c) 2019 by Christina D'Astolfo.
:license: Apache2, see LICENSE for more details.
"""

from .__version__ import __version__
from .resources import ItemResource, UpdateResource, TagResource, BoardResource, UserResource, GroupResource, ComplexityResource, WorkspaceResource, NotificationResource


class MondayClient:
    def __init__(self, token):
        """
        :param token: API Token for the new :class:`BaseResource` object.
        """
        self.items = ItemResource(token=token)
        self.updates = UpdateResource(token=token)
        self.tags = TagResource(token=token)
        self.boards = BoardResource(token=token)
        self.users = UserResource(token=token)
        self.groups = GroupResource(token=token)
        self.complexity = ComplexityResource(token=token)
        self.workspaces = WorkspaceResource(token=token)
        self.notifications = NotificationResource(token=token)

    def __str__(self):
        return f'MondayClient {__version__}'

    def __repr__(self):
        return f'MondayClient {__version__}'



from .items import ItemResource
from .updates import UpdateResource
from .tags import TagResource
from .boards import BoardResource
from .users import UserResource
from .groups import GroupResource
from .complexity import ComplexityResource
from .workspaces import WorkspaceResource
from .notification import NotificationResource

__all__ = ['ItemResource', 'UpdateResource', 'TagResource', 'BoardResource', 'UserResource', 'GroupResource', 'ComplexityResource', 'WorkspaceResource', 'NotificationResource']



from monday.resources.base import BaseResource
from monday.query_joins import (get_workspaces_query, create_workspace_query,
                                add_users_to_workspace_query, delete_users_from_workspace_query,
                                add_teams_to_workspace_query, delete_teams_from_workspace_query)


class WorkspaceResource(BaseResource):
    def __init__(self, token):
        super().__init__(token)

    def get_workspaces(self):
        query = get_workspaces_query()
        return self.client.execute(query)
    
    def create_workspace(self, name, kind, description=""):
        query = create_workspace_query(name, kind, description)
        return self.client.execute(query)
    
    def add_users_to_workspace(self, workspace_id, user_ids, kind):
        query = add_users_to_workspace_query(workspace_id, user_ids, kind)
        return self.client.execute(query)
    
    def delete_users_from_workspace(self, workspace_id, user_ids):
        query = delete_users_from_workspace_query(workspace_id, user_ids)
        return self.client.execute(query)
    
    def add_teams_to_workspace(self, workspace_id, team_ids):
        query = add_teams_to_workspace_query(workspace_id, team_ids)
        return self.client.execute(query)
    
    def delete_teams_from_workspace(self, workspace_id, team_ids):
        query = delete_teams_from_workspace_query(workspace_id, team_ids)
        return self.client.execute(query)
    


from monday.resources.base import BaseResource
from monday.query_joins import get_users_query


class UserResource(BaseResource):
    def __init__(self, token):
        super().__init__(token)

    def fetch_users(self, **kwargs):
        query = get_users_query(**kwargs)
        return self.client.execute(query)



#!/usr/bin/env python3
from setuptools import setup

from monday import __author__, __email__, __version__

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(name='monday',
      version=__version__,
      description='A Python client library for Monday.com',
      long_description=long_description,
      long_description_content_type='text/markdown; charset=UTF-8',
      author=__author__,
      author_email=__email__,
      packages=['monday', 'monday.resources', 'monday.graphqlclient'],
      url='https://github.com/ProdPerfect/monday',
      include_package_data=True,
      zip_safe=False,
      license='BSD',
      python_requires='>=3.6',
      classifiers=[
          "Programming Language :: Python :: 3",
          "Programming Language :: Python :: 3.6",
          "Programming Language :: Python :: 3.7",
          "Programming Language :: Python :: 3.8",
          "Operating System :: OS Independent",
      ])
